summaryrefslogtreecommitdiffstats
path: root/kbugbuster/backend/bug.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbugbuster/backend/bug.h')
-rw-r--r--kbugbuster/backend/bug.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kbugbuster/backend/bug.h b/kbugbuster/backend/bug.h
index 406179c8..e60b0e98 100644
--- a/kbugbuster/backend/bug.h
+++ b/kbugbuster/backend/bug.h
@@ -17,7 +17,7 @@ public:
enum Severity { SeverityUndefined, Critical, Grave, Major, Crash, Normal,
Minor, Wishlist };
- enum Status { StatusUndefined, Unconfirmed, New, Assigned, Reopened,
+ enum tqStatus { StatusUndefined, Unconfirmed, New, Assigned, Reopened,
Closed };
Bug();
@@ -55,23 +55,23 @@ public:
BugMergeList mergedWith() const;
/**
* Status of a bug. Currently open or closed.
* TODO: Should we add a status 'deleted' here ?
*/
- Status status() const;
- void setStatus( Status newStatus );
+ tqStatus status() const;
+ void settqStatus( tqStatus newtqStatus );
- static TQString statusLabel( Status s );
+ static TQString statusLabel( tqStatus s );
/**
Return string representation of status. This function is symmetric to
- stringToStatus().
+ stringTotqStatus().
*/
- static TQString statusToString( Status s );
+ static TQString statusToString( tqStatus s );
/**
Return status code of string representation. This function is symmetric
to statusToString().
*/
- static Status stringToStatus( const TQString &, bool *ok = 0 );
+ static tqStatus stringTotqStatus( const TQString &, bool *ok = 0 );
bool operator==( const Bug &rhs );
bool operator<( const Bug &rhs ) const;
@@ -55,23 +55,23 @@ public:
BugMergeList mergedWith() const;
/**
- * Status of a bug. Currently open or closed.
+ * tqStatus of a bug. Currently open or closed.
* TODO: Should we add a status 'deleted' here ?
*/